@@ -166,7 +166,8 @@ class Application(ConfigurableForServerSidePath):
         # Initialize task manager:
         if self._server.isPersistent():
             from TaskKit.Scheduler import Scheduler
-            self._taskManager = Scheduler(1, exceptionHandler=self.handleException)
+            self._taskManager = Scheduler(daemon=True,
+                exceptionHandler=self.handleException)
             self._taskManager.start()
         else:
             self._taskManager = None
