@@ -4,7 +4,7 @@ import cgi
 import os
 import sys
 import traceback
-from operator import itemgetter
+from operator import attrgetter, itemgetter
 from time import time
 
 from MiscUtils import NoDefault
@@ -103,28 +103,34 @@ class HTTPRequest(Request):
 
         # We use the cgi module to get the fields,
         # but then change them into an ordinary dictionary of values:
-        fields = {}
+        fieldStorage, fields = self._fields, {}
         try:
-            fieldKeys = self._fields.keys()
-        except TypeError:
+            # Avoid accessing fieldStorage as dict; that would be very slow
+            # as it always iterates over all items to find a certain key.
+            # Instead, iterate directly over the items of the internal list.
+            fieldItems = fieldStorage.list
+        except AttributeError:
             # This can happen if we do not have a a regular POST
             # from an HTML form, but, for example, an XML-RPC request.
-            pass
-        else:
-            for key in fieldKeys:
-                value = self._fields[key]
-                if isinstance(value, list):
-                    # we have a list of cgi.MiniFieldStorage objects
-                    value = [item.value for item in value]
+            fieldItems = None
+            if debug:
+                print "Cannot get fieldstorage list."
+        if fieldItems:
+            for value in fieldItems:
+                fields.setdefault(value.name, []).append(value)
+            getValue = attrgetter('value')
+            for key, value in fields.iteritems():
+                if len(value) > 1:
+                    value = map(getValue, value)
                 else:
+                    value = value[0]
                     if value.filename:
                         if debug:
-                            print "Uploaded file found"
-                    else: # i.e., if we don't have a list,
-                        # we have one of those cgi.MiniFieldStorage objects
-                        value = value.value # get its value
+                            print "Uploaded file found:", value.filename
+                    else:
+                        value = value.value
                 fields[key] = value
-        self._fieldStorage, self._fields = self._fields, fields
+        self._fieldStorage, self._fields = fieldStorage, fields
 
         # We use Tim O'Malley's Cookie class to get the cookies,
         # but then change them into an ordinary dictionary of values
@@ -139,7 +145,7 @@ class HTTPRequest(Request):
         self._pathInfo = self.pathInfo()
 
         if debug:
-            print "Done setting up request, found keys %r" % fieldKeys
+            print "Done setting up request, found keys %r" % fields.keys()
 
 
     ## Protocol ##
@@ -447,7 +453,7 @@ class HTTPRequest(Request):
             return host
 
     def serverURL(self, canonical=False):
-        """Return the full internet path to this request.
+        """Return the full Internet path to this request.
 
         This is the URL that was actually received by the webserver
         before any rewriting took place. If canonical is set to true,
@@ -457,14 +463,14 @@ class HTTPRequest(Request):
         i.e. http://www.my.own.host.com:8080/WebKit/TestPage.py
 
         """
-        if canonical and 'SCRIPT_URI' in environ:
+        if canonical and 'SCRIPT_URI' in self._environ:
             return self._environ['SCRIPT_URI']
         else:
             return '%s://%s%s' % (
                 self.scheme(), self.hostAndPort(), self.serverPath())
 
     def serverURLDir(self):
-        """Return the directory of the URL in full internet form.
+        """Return the directory of the URL in full Internet form.
 
         Same as serverURL, but removes the actual page.
 
@@ -484,9 +490,14 @@ class HTTPRequest(Request):
 
         """
         if 'SCRIPT_URL' in self._environ:
-            return self._environ['SCRIPT_URL']
+            path = self._environ['SCRIPT_URL']
         else:
-            return self._servletPath + self._pathInfo
+            path = self._servletPath
+            if not self._absolutepath and self._stack:
+                path += self._stack[0][1]
+            else:
+                path += self._pathInfo
+        return path
 
     def serverPathDir(self):
         """Return the directory of the webserver URL path.
